#!/busybox/sh

set -euo pipefail
git fetch

CURRENTTAG=$(git tag --sort=-taggerdate | head -n 1)
PREVIOUSTAG=$(git tag --sort=-taggerdate | head -n 2 | tail -n 1)
ALLCHANGES=$(npx -y @philippdormann/changelogen@latest --from $PREVIOUSTAG --to $CURRENTTAG --no-output | sed 's/"/\\"/g' | tail -n +6)
FORMATTED_CHANGES=$(echo "# $CURRENTTAG \n $ALLCHANGES" | pandoc -f markdown -t html | sed 's/"/'"'"'/g' | xargs echo -n)

if [[ -n "${PLUGIN_GITEA_DOMAIN:-}" ]]; then
    curl --request POST \
    --url "https://$PLUGIN_GITEA_DOMAIN/api/v1/repos/$PLUGIN_REPO/releases" \
    --header "Content-Type: application/json" \
    --header "Authorization: token $APIKEY" \
    --data "{
        \"name\": \"$DRONE_TAG\",
        \"body\": \"$ALLCHANGES\",
        \"draft\": false,
        \"tag_name\": \"$DRONE_TAG\"
    }"
fi
if [[ -n "${PLUGIN_MATRIX_SERVER:-}" ]]; then
    MATRIX_LOGIN=$(curl --request POST \
        --url "https://$PLUGIN_MATRIX_SERVER/_matrix/client/r0/login" \
        --header "Content-Type: application/json" \
        --data "{
          \"type\": \"m.login.password\",
          \"user\": \"$PLUGIN_MATRIX_USER\",
          \"password\": \"$PLUGIN_MATRIX_PASSWORD\"
        }")
    MATRIX_TOKEN=$(echo $MATRIX_LOGIN | jq .access_token | sed 's/"/\/g' )
    curl --request POST \
        --url "https://$PLUGIN_MATRIX_SERVER/_matrix/client/r0/rooms/!YHENYmWYHrPltyHVeb:matrix.org/send/m.room.message?access_token=$MATRIX_TOKEN" \
        --header "Content-Type: application/json" \
        --data "{
          \"msgtype\": \"m.text\",
          \"body\": \"$(echo "# $CURRENTTAG \n $ALLCHANGES" | xargs echo -n)\",
          \"format\": \"org.matrix.custom.html\",
          \"formatted_body\": \"$FORMATTED_CHANGES\"
        }"
fi